@@ -8,6 +8,8 @@ from mqtt_hass_base.error import MQTTHassBaseError
 
 ENTITY_TYPES = (
     "switch",
+    "lock",
+    "light",
     "binarysensor",
     "sensor",
     "vacuum",
@@ -32,6 +34,10 @@ class MqttDevice:
         self._connections = []
         self._mac = None
 
+    def __repr__(self):
+        """Get repr of the current device."""
+        return "<{} '{}'>".format(self.__class__.__name__, self.name)
+
     @property
     def entities(self):
         """Get the list of the entities of the devices."""
@@ -100,7 +106,7 @@ class MqttDevice:
     @name.setter
     def name(self, name: str):
         if name != self._name:
-            self.logger = self.logger.getChildren("device").getChildren(name)
+            self.logger = self.logger.getChild("device").getChild(name)
         self._name = name
 
     @property
@@ -169,9 +175,9 @@ class MqttDevice:
         try:
             item = list(raw_item)
         except TypeError:
-            raise Exception("Bad connection value: {}".format(raw_item))
+            raise MQTTHassBaseError("Bad connection value: {}".format(raw_item))
         if len(item) != 2:
-            raise Exception(
+            raise MQTTHassBaseError(
                 "A connection need 2 elements but it's: {}".format(raw_item)
             )
         if item not in self._connections:
@@ -197,4 +203,8 @@ class MqttDevice:
             payload["sw_version"] = self.sw_version
         if self.via_device:
             payload["via_device"] = self.via_device
+        if "connections" not in payload and "identifiers" not in payload:
+            msg = "You need to define identifiers or connections in the device attributes."
+            self.logger.error(msg)
+            raise MQTTHassBaseError(msg)
         return payload
